@@ -47,7 +47,6 @@
 #ifdef WIN32
 #include <mbstring.h>
 #include <windows.h>
-#define snprintf _snprintf
 /* Undef the similar macro from pthread.h, it doesn't check if
  * gmtime() returns NULL.
  */
@@ -1596,7 +1595,21 @@ fetch_lat_long_from_string  (const char *str, int *latitude_degrees, int *latitu
 	len = sptr - loc;
 	location = strncpy (location, loc, len);
 	location [len] = '\0';
-	
+
+#if defined(sun) && defined(__SVR4)
+    /* Handle EET, MET and WET in zone_sun.tab. */
+    if (!strcmp (location, "Europe/")) {
+        while (*sptr != '\t')
+            sptr++;
+        loc = ++sptr;
+        while (!isspace (*sptr))
+            sptr++;
+        len = sptr - loc;
+        location = strncpy (location, loc, len);
+        location [len] = '\0';
+    }
+#endif
+
 	lon = lat + 1;
 	while (*lon != '+' && *lon != '-')
 		lon++;
